summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepicture.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepicture.h')
-rw-r--r--kopete/libkopete/kopetepicture.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopetepicture.h b/kopete/libkopete/kopetepicture.h
index 7b8de0d4..555787df 100644
--- a/kopete/libkopete/kopetepicture.h
+++ b/kopete/libkopete/kopetepicture.h
@@ -23,7 +23,7 @@
#include <tqimage.h>
-namespace KABC
+namespace TDEABC
{
class Picture;
}
@@ -74,9 +74,9 @@ public:
*/
Picture(const TQImage &image);
/**
* Create a picture from a KABC::Picture.
*/
- Picture(const KABC::Picture &picture);
+ Picture(const TDEABC::Picture &picture);
/**
* Copy a picture. It doesn't create a full copy, it just make a reference.
*/
@@ -131,7 +131,7 @@ public:
* Set the picture content.
* @param picture a KABC Picture.
*/
- void setPicture(const KABC::Picture &picture);
+ void setPicture(const TDEABC::Picture &picture);
private:
/**
@@ -74,9 +74,9 @@ public:
Picture(const TQImage &image);
/**
- * Create a picture from a KABC::Picture.
+ * Create a picture from a TDEABC::Picture.
*/